clear mata
clear matrix
clear programs

*USES NONLINEAR PROGRAM IN http://www.stata.com/support/faqs/programming/system-of-nonlinear-equations/
*GETS NET GAIN AFTER GETTING RID OF MIGRATION COSTS
*USES R = 4, BUT EASY TO CHANGE FOR OTHER ASSUMPTIONS
*USES 150K MIGRATION COSTS PER PERSON TO ILLUSTRATE THE PROGRAM;

input R
2
3
4
5
6
end

list

#delimit ;
set more 1;
log using /volumes/ddisk/immigration/programs/chapter_7/Alternative_Note_7_24.log, replace;

*NOTE ALL NUMBERS ARE IN BILLIONS;
generate gdp=70000;
generate labor0 = 2.7;
generate labor1 = 0.6;
generate delta = -0.3;

*R is the ratio of wages;
*A is the ratio of the alphas, alpha1/alpha0;
generate A = R*(labor0/labor1)^delta;
generate k = A^(1/delta);
generate M = (labor0 - k*labor1)/(1 + k);

*NOW GET VALUE OF THE CONSTANTS ALPHA1 AND ALPHA0;
*SOLVE FOR ALPHA0;

generate numer = (1 + delta)*gdp;
generate denom = A*(labor1^(1+delta)) + labor0^(1+delta);
generate alpha0 = numer/denom;
generate alpha1 = A*alpha0;

list R alpha0 alpha1;

save /volumes/ddisk/data/junkgain.dta, replace;



clear;
#delimit cr


program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]

        tempvar yh
        gen double `yh' = `z' - 32970.93*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 12943.0*(2.7-`m')^-.3 - (.05*150000)*((5.9*`m')/2.7) in 2

        replace `varlist' = `yh'

end


clear
set obs 2
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m) initial(z 1 m 1)


generate mhat=_b[/m]

keep if _n==1
keep mhat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
summ mhat2;
drop mhat;
rename mhat2 mhat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate gain = gain1 - gain0 - 7500*movers;
generate pgain = gain/gdp;

list R gain pgain mhat movers;





**************************************;
*THIS SET ASSUMES MIGRATION COSTS ARE ZERO SO WE END UP BACK IN EXAMPLE ILLUSTRATED IN BOOK;




clear;
#delimit cr

clear mata
clear matrix
clear programs


program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]

        tempvar yh
        gen double `yh' = `z' - 32970.93*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 12943.0*(2.7-`m')^-.3 - (.05*0)*((5.9*`m')/2.7) in 2

        replace `varlist' = `yh'

end


clear
set obs 2
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m) initial(z 1 m 1)


generate mhat=_b[/m]

keep if _n==1
keep mhat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
summ mhat2;
drop mhat;
rename mhat2 mhat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate gain = gain1 - gain0 - 0*movers;
generate pgain = gain/gdp;

list R gain pgain mhat movers;




log close;


