clear mata
clear matrix
clear programs

*GETS BREAKEVEN LEVEL OF COSTS AND GAINS WHEN PEOPLE TAKE MIGRATION COSTS INTO ACCOUNT
*AND WAGES ARE NOT COMPLETELY EQUALIZED ACROSS REGIONS

*USES NONLINEAR PROGRAM IN http://www.stata.com/support/faqs/programming/system-of-nonlinear-equations/

input R
2
3
4
5
6
end

list

#delimit ;
set more 1;
log using /volumes/ddisk/immigration/programs/chapter_7/Note_7_24.log, replace;

*NOTE ALL NUMBERS ARE IN BILLIONS;
generate gdp=70000;
generate labor0 = 2.7;
generate labor1 = 0.6;
generate delta = -0.3;

*R is the ratio of wages;
*A is the ratio of the alphas, alpha1/alpha0;
generate A = R*(labor0/labor1)^delta;
generate k = A^(1/delta);
generate M = (labor0 - k*labor1)/(1 + k);

*NOW GET VALUE OF THE CONSTANTS ALPHA1 AND ALPHA0;
*SOLVE FOR ALPHA0;

generate numer = (1 + delta)*gdp;
generate denom = A*(labor1^(1+delta)) + labor0^(1+delta);
generate alpha0 = numer/denom;
generate alpha1 = A*alpha0;

list R alpha0 alpha1;

save /volumes/ddisk/data/junkgain.dta, replace;




*SET A, CASE WHERE R = 2;

clear;
#delimit cr


program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m c
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]
        scalar `c' = `at'[1, 3]

        tempvar yh
        gen double `yh' = `z' - 21557.92*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 16925.46*(2.7-`m')^-.3 - (.05*`c')*((5.9*`m')/2.7) in 2
        replace `yh' = (.05*`c')*((5.9*`m')/2.7) - (21557.92/(1-.3))*((.6+`m')^(1-.3) - .6^(1-.3)) + (16925.46/(1-.3))*((2.7^(1-.3)) - (2.7-`m')^(1-.3)) in 3

        replace `varlist' = `yh'

end


clear
set obs 3
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m c) initial(z 1 m 1 c 1)

generate mhat=_b[/m]
generate chat=_b[/c]

keep if _n==1
keep mhat chat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
egen chat2=mean(chat);
summ mhat2 chat2;
drop mhat chat;
rename mhat2 mhat;
rename chat2 chat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate dgain = gain1 - gain0;
generate gain = gain1 - gain0 - .05*chat*movers;
generate pgain = gain/gdp;

generate newgain = (21557.92/(1-.3))*((.6+mhat)^(1-.3) - .6^(1-.3)) 
	- (16925.46/(1-.3))*((2.7^(1-.3)) - (2.7-mhat)^(1-.3)) - (.05*chat)*((5.9*mhat)/2.7);

list R dgain gain newgain pgain;

drop mrate movers;











********************************************************************;


*SET B, CASE WHERE R = 3;

clear;
#delimit cr

clear mata
clear matrix
clear programs

program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m c
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]
        scalar `c' = `at'[1, 3]

        tempvar yh
        gen double `yh' = `z' - 28025.29*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 14668.74*(2.7-`m')^-.3 - (.05*`c')*((5.9*`m')/2.7) in 2
        replace `yh' = (.05*`c')*((5.9*`m')/2.7) - (28025.29/(1-.3))*((.6+`m')^(1-.3) - .6^(1-.3)) + (14668.74/(1-.3))*((2.7^(1-.3)) - (2.7-`m')^(1-.3)) in 3

        replace `varlist' = `yh'

end


clear
set obs 3
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m c) initial(z 1 m 1 c 1)

generate mhat=_b[/m]
generate chat=_b[/c]

keep if _n==1
keep mhat chat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
egen chat2=mean(chat);
summ mhat2 chat2;
drop mhat chat;
rename mhat2 mhat;
rename chat2 chat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate dgain = gain1 - gain0;
generate gain = gain1 - gain0 - .05*chat*movers;
generate pgain = gain/gdp;

generate newgain = (28025.29/(1-.3))*((.6+mhat)^(1-.3) - .6^(1-.3)) 
	- (14668.74/(1-.3))*((2.7^(1-.3)) - (2.7-mhat)^(1-.3)) - (.05*chat)*((5.9*mhat)/2.7);

list R dgain gain newgain pgain;

drop mrate movers;







********************************************************************;


*SET C, CASE WHERE R = 4;

clear;
#delimit cr

clear mata
clear matrix
clear programs


program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m c
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]
        scalar `c' = `at'[1, 3]

        tempvar yh
        gen double `yh' = `z' - 32970.93*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 12943.0*(2.7-`m')^-.3 - (.05*`c')*((5.9*`m')/2.7) in 2
        replace `yh' = (.05*`c')*((5.9*`m')/2.7) - (32970.93/(1-.3))*((.6+`m')^(1-.3) - .6^(1-.3)) + (12943.0/(1-.3))*((2.7^(1-.3)) - (2.7-`m')^(1-.3)) in 3

        replace `varlist' = `yh'

end


clear
set obs 3
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m c) initial(z 1 m 1 c 1)

generate mhat=_b[/m]
generate chat=_b[/c]

keep if _n==1
keep mhat chat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
egen chat2=mean(chat);
summ mhat2 chat2;
drop mhat chat;
rename mhat2 mhat;
rename chat2 chat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate dgain = gain1 - gain0;
generate gain = gain1 - gain0 - .05*chat*movers;
generate pgain = gain/gdp;

generate newgain = (32970.93/(1-.3))*((.6+mhat)^(1-.3) - .6^(1-.3)) 
	- (12943.0/(1-.3))*((2.7^(1-.3)) - (2.7-mhat)^(1-.3)) - (.05*chat)*((5.9*mhat)/2.7);

list R dgain gain newgain pgain;

drop mrate movers;







********************************************************************;


*SET D, CASE WHERE R = 5;

clear;
#delimit cr

clear mata
clear matrix
clear programs


program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m c
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]
        scalar `c' = `at'[1, 3]

        tempvar yh
        gen double `yh' = `z' - 36875.39*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 11580.58*(2.7-`m')^-.3 - (.05*`c')*((5.9*`m')/2.7) in 2
        replace `yh' = (.05*`c')*((5.9*`m')/2.7) - (36875.39/(1-.3))*((.6+`m')^(1-.3) - .6^(1-.3)) + (11580.58/(1-.3))*((2.7^(1-.3)) - (2.7-`m')^(1-.3)) in 3

        replace `varlist' = `yh'

end


clear
set obs 3
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m c) initial(z 1 m 1 c 1)

generate mhat=_b[/m]
generate chat=_b[/c]

keep if _n==1
keep mhat chat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
egen chat2=mean(chat);
summ mhat2 chat2;
drop mhat chat;
rename mhat2 mhat;
rename chat2 chat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate dgain = gain1 - gain0;
generate gain = gain1 - gain0 - .05*chat*movers;
generate pgain = gain/gdp;

generate newgain = (36875.39/(1-.3))*((.6+mhat)^(1-.3) - .6^(1-.3)) 
	- (11580.58/(1-.3))*((2.7^(1-.3)) - (2.7-mhat)^(1-.3)) - (.05*chat)*((5.9*mhat)/2.7);

list R dgain gain newgain pgain;

drop mrate movers;








********************************************************************;


*SET E, CASE WHERE R = 6;

clear;
#delimit cr

clear mata
clear matrix
clear programs


program nlfaq
 
        syntax varlist(min=1 max=1) [if], at(name)

        tempname z m c
        scalar `z' = `at'[1, 1]
        scalar `m' = `at'[1, 2]
        scalar `c' = `at'[1, 3]

        tempvar yh
        gen double `yh' = `z' - 40036.14*(.6+`m')^-.3 + 1 in 1
        replace `yh' = `z' - 10477.67*(2.7-`m')^-.3 - (.05*`c')*((5.9*`m')/2.7) in 2
        replace `yh' = (.05*`c')*((5.9*`m')/2.7) - (40036.14/(1-.3))*((.6+`m')^(1-.3) - .6^(1-.3)) + (10477.67/(1-.3))*((2.7^(1-.3)) - (2.7-`m')^(1-.3)) in 3

        replace `varlist' = `yh'

end


clear
set obs 3
generate y = 0
replace y = 1 in 1

nl faq @ y, parameters(z m c) initial(z 1 m 1 c 1)

generate mhat=_b[/m]
generate chat=_b[/c]

keep if _n==1
keep mhat chat

#delimit ;

append using /volumes/ddisk/data/junkgain.dta;
egen mhat2=mean(mhat);
egen chat2=mean(chat);
summ mhat2 chat2;
drop mhat chat;
rename mhat2 mhat;
rename chat2 chat;
drop if R==.;


*NOW GET THE CHANGE IN GDP;
*SOLVE TWO TERMS SEPARATELY AND THEN ADD;
*AND IT WILL BE ANNUALIZED TO TAKE ACCOUNT OF PV ISSUE WHEN I SUBTRACT OUT COSTS;

generate new1 = labor1+mhat;
generate new0 = labor0-mhat;

*CALCULATING NUMBER OF MOVERS IN TERMS OF PERSONS, NOT WORKERS;
generate mrate = mhat/labor0;
generate double movers = mrate*5.9;

generate gain1 = (alpha1/(1+delta))*(new1^(1+delta) - labor1^(1+delta));
generate gain0 = (alpha0/(1+delta))*(labor0^(1+delta) - new0^(1+delta));
generate dgain = gain1 - gain0;
generate gain = gain1 - gain0 - .05*chat*movers;
generate pgain = gain/gdp;

generate newgain = (40036.14/(1-.3))*((.6+mhat)^(1-.3) - .6^(1-.3)) 
	- (10477.67/(1-.3))*((2.7^(1-.3)) - (2.7-mhat)^(1-.3)) - (.05*chat)*((5.9*mhat)/2.7);

list R dgain gain newgain pgain;

drop mrate movers;



log close;


